@@ -201,66 +201,70 @@ c
        if(code .ge. 1 .and. code .le. klast) then
 c                   this should be consistent with regptcl/antip
 c                   def. in Zcode.h
-            if(code .eq. kelec .or. code .eq. kmuon ) then
-                 p.subcode = - charge * regptcl
-            elseif(code .eq. kpion .or. code .eq. kkaon
-     *             .or. code .eq. knuc) then
-                 p.subcode =  charge * regptcl
-                 if( code .eq. kkaon .and. charge .eq. 0 .and.
-     *                 subcode .ne. 0) then
-                      if(subcode .eq. k0s .or. 
-     *                   subcode .eq. k0l ) then
-                           p.subcode = subcode
-                      else
-                           write(msg,*) ' strange subcode=', 
-     *                     subcode,' to cssubc. code=', code
-                           call cerrorMsg(msg, 0)
-                      endif
-                 elseif(code .eq. knuc .and. charge .eq. 0 
-     *                .and.   subcode .ne. 0) then
-                      if(subcode .eq. kneutron .or.
-     *                   subcode .eq. kneutronb) then
-                           p.subcode = subcode
-                      else
-                           write(msg, *) ' strange subcode=', 
-     *                     subcode, ' to cssubc. code=', code
-                           call cerrorMsg(msg, 0)
-                      endif
-                   endif
-            elseif(code .eq. kdmes) then
-                 if(subcode .ne. 0 .and. charge .eq. 0)then
-                       if(subcode .eq. kd0 .or.
-     *                    subcode .eq. kd0b) then                       
-                           p.subcode = subcode
-                       endif
-                  else
-                       p.subcode = charge * regptcl
-                  endif
-            elseif(code .ge. kdeut .and. code .le. khvymax) then
-                  p.subcode = isign(1, charge) *regptcl
-            elseif(code .eq. ktriton ) then
-                  p.subcode = isign(1, charge) *regptcl
-            elseif(code .eq. kneumu .or. code .eq. kneue) then
-               if(subcode .eq. regptcl .or.
-     *              subcode .eq. antip .or.
-     *              subcode .eq. 0  ) then
-                  p.subcode = subcode
-               else
-                  write(msg, *) ' strange subcode=', 
-     *                 subcode, ' to cssubc. code=', code
-                  call cerrorMsg(msg,  0)
-               endif   
-            elseif(code .ge. klambda .and.
-     *             code .le. klambdac) then
-               p.subcode = subcode
-            else      
-                 p.subcode = 0          ! should be fixed later
-            endif     
+          if(code .eq. kphoton) then
+             p.subcode = subcode
+          elseif(code .eq. kelec .or. code .eq. kmuon ) then
+             p.subcode = - charge * regptcl
+          elseif(code .eq. kpion .or. code .eq. kkaon
+     *            .or. code .eq. knuc) then
+             p.subcode =  charge * regptcl
+             if( code .eq. kkaon .and. charge .eq. 0 .and.
+     *            subcode .ne. 0) then
+                if(subcode .eq. k0s .or. 
+     *               subcode .eq. k0l ) then
+                   p.subcode = subcode
+                else
+                   write(msg,*) '1 strange subcode=', 
+     *                  subcode,' to cssubc. code=', code
+                   p.mass = -1.0
+                   p.mass = sqrt(p.mass)
+                   call cerrorMsg(msg, 0)
+                endif
+             elseif(code .eq. knuc .and. charge .eq. 0 
+     *               .and.   subcode .ne. 0) then
+                if(subcode .eq. kneutron .or.
+     *               subcode .eq. kneutronb) then
+                   p.subcode = subcode
+                else
+                   write(msg, *) '2 strange subcode=', 
+     *                  subcode, ' to cssubc. code=', code
+                   call cerrorMsg(msg, 0)
+                endif
+             endif
+          elseif(code .eq. kdmes) then
+             if(subcode .ne. 0 .and. charge .eq. 0)then
+                if(subcode .eq. kd0 .or.
+     *               subcode .eq. kd0b) then                       
+                   p.subcode = subcode
+                endif
+             else
+                p.subcode = charge * regptcl
+             endif
+          elseif(code .ge. kdeut .and. code .le. khvymax) then
+             p.subcode = isign(1, charge) *regptcl
+          elseif(code .eq. ktriton ) then
+             p.subcode = isign(1, charge) *regptcl
+          elseif(code .eq. kneumu .or. code .eq. kneue) then
+             if(subcode .eq. regptcl .or.
+     *            subcode .eq. antip .or.
+     *            subcode .eq. 0  ) then
+                p.subcode = subcode
+             else
+                write(msg, *) ' 3 strange subcode=', 
+     *               subcode, ' to cssubc. code=', code
+                call cerrorMsg(msg,  0)
+             endif   
+          elseif(code .ge. klambda .and.
+     *            code .le. klambdac) then
+             p.subcode = subcode
+          else      
+             p.subcode = 0      ! should be fixed later
+          endif     
        elseif(code .eq. krare) then
-            p.subcode = 0
+          p.subcode = 0
        else     
-            write(msg, *) ' code=',code,' invalid to cssubc'
-            call cerrorMsg(msg, 0)
+          write(msg, *) ' code=',code,' invalid to cssubc'
+          call cerrorMsg(msg, 0)
        endif
       end
 c     ****************************************************
