@@ -140,8 +140,6 @@ c             use i-th segment
            endif     
          endif  
          end
-c            convert sampled energy/momentum into Cosmos
-c            particle energy (Total energy in GeV)
          subroutine cconv_prim_e(prm)
          implicit none
 
@@ -150,41 +148,45 @@ c            particle energy (Total energy in GeV)
 #include  "Zprimary.h"
          record /primaries/ prm
          integer label, code, massn
-c
+c       
+         real*8 seinGeV  ! sampled primary in GeV
+
          label = prm.label
 c
+         seinGeV= prm.sampled_e *   prm.each(label).togev
          call cmkptc(prm.each(label).code,
      *               prm.each(label).subcode,
      *               prm.each(label).charge,
      *               prm.particle)        
          if(prm.each(label).etype .eq. 'e/p' .or.
      *      prm.each(label).etype .eq. 'e') then
-            prm.particle.fm.p(4) = prm.sampled_e
+            prm.particle.fm.p(4) = seinGeV
+     *                  
          elseif(prm.each(label).etype .eq.'p/p' .or.
      *      prm.each(label).etype .eq. 'p')then
             prm.particle.fm.p(4) = sqrt(prm.particle.mass**2 +
-     *             prm.sampled_e**2)
+     *             seinGeV**2)
          elseif(prm.each(label).etype .eq. 'ke/p' .or.
      *      prm.each(label).etype .eq. 'ke') then
-            prm.particle.fm.p(4) = prm.sampled_e + prm.particle.mass
+            prm.particle.fm.p(4) = seinGeV + prm.particle.mass
          elseif(prm.each(label).etype .eq. 'e/n') then
             code = prm.each(label).code
             if(code .ge. kdeut .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
-               prm.particle.fm.p(4) = massn *prm.sampled_e
+               prm.particle.fm.p(4) = massn * seinGeV
             else
-               prm.particle.fm.p(4) = prm.sampled_e
+               prm.particle.fm.p(4) =  seinGeV
             endif
          elseif(prm.each(label).etype .eq. 'ke/n') then
             code = prm.each(label).code
             if(code .ge. kdeut .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
-               prm.particle.fm.p(4) = massn *prm.sampled_e + 
+               prm.particle.fm.p(4) = massn * seinGeV +
      *            prm.particle.mass
             else
-               prm.particle.fm.p(4) = prm.sampled_e +
+               prm.particle.fm.p(4) = seinGeV +
      *            prm.particle.mass
             endif
 	 elseif(prm.each(label).etype .eq. 'p/n') then
@@ -193,10 +195,10 @@ c
      *         code .le. khvymax) then
                call cghvm(code, massn)
                prm.particle.fm.p(4) =
-     *      	  sqrt( (massn * prm.sampled_e) **2 + 
+     *      	  sqrt( (massn * seinGeV) **2 + 
      *            prm.particle.mass **2)
             else
-               prm.particle.fm.p(4) = sqrt(prm.sampled_e**2 +
+               prm.particle.fm.p(4) = sqrt(seinGeV**2 +
      *            prm.particle.mass**2)
             endif
          else
@@ -205,8 +207,6 @@ c
      *                  prm.each(label).symb
             stop 9999
          endif
-         prm.particle.fm.p(4) =
-     *        prm.particle.fm.p(4) * prm.each(label).togev
         end
 c       *******************************************************
 c       *  cqPrimE: inquire sampled primary energy or p
@@ -289,3 +289,4 @@ c
         record /primaries/ prm
         prm = Prim
         end
+
